@@ -434,6 +434,18 @@ public:
 	inline operator bool() const
 		{return bufsize > 0 || context != NULL;};
 
+	/**
+	 * Finalize and recycle current digest to start a new
+	 * digest.
+	 * @param binary digest used rather than text if true.
+	 */
+	void recycle(bool binary = false);
+
+	/**
+	 * Reset and restart digest object.
+	 */
+	void reset(void);
+
 	/**
 	 * Test to see if a specific digest type is supported.
 	 * @param name of digest we want to check.
