@@ -202,3 +202,47 @@ context::~context()
 		SSL_CTX_free(ctx);
 }
 
+void secure::uuid(char *str)
+{
+	static unsigned char buf[16];
+	static Timer::tick_t prior = 0l;
+	static unsigned short seq;
+	Timer::tick_t current = Timer::ticks();
+
+	Mutex::protect(&buf);
+
+	// get our (random) node identifier...
+	if(!prior)	
+		Random::fill(buf + 10, 6);
+	
+	if(current == prior)
+		++seq;
+	else
+		Random::fill((unsigned char *)&seq, sizeof(seq));
+
+	buf[8] = (unsigned char)((seq >> 8) & 0xff);
+	buf[9] = (unsigned char)(seq & 0xff);
+	buf[3] = (unsigned char)(current & 0xff);
+	buf[2] = (unsigned char)((current >> 8) & 0xff);
+	buf[1] = (unsigned char)((current >> 16) & 0xff);
+	buf[0] = (unsigned char)((current >> 24) & 0xff);
+	buf[5] = (unsigned char)((current >> 32) & 0xff);
+	buf[4] = (unsigned char)((current >> 40) & 0xff);
+	buf[7] = (unsigned char)((current >> 48) & 0xff);
+	buf[6] = (unsigned char)((current >> 56) & 0xff);
+
+	buf[6] &= 0x0f;
+	buf[6] |= 0x10;
+	buf[8] |= 0x80;
+	String::hexdump(buf, str, "4-2-2-2-6");
+	Mutex::release(&buf);
+}
+
+String secure::uuid(void)
+{
+	char buf[38];
+	uuid(buf);
+	return String(buf);
+}
+
+
